#R-Code based on data collected and analysed for the article "Exploring systematic orthographic crosslinguistic similarities to enhance foreign language vocabulary learning" by Nina Selina Hicks (-Mueller), accepted for publication in Language Teaching Research (September 2021)

#Code organized by:
###Import and organize data
###Initial differences
###Improvement by treatment and Yes/No test
###Linear mixed effect regression model

library("tidyverse")
library("ggplot2")
library("lme4")
library("lmerTest")
library("ggpubr")

###################### IMPORT AND ORGANIZE DATA ########################

data <- read.csv("dataArticle2021.csv") #complete data
summary(data)
#wnw_istd = Index of Signal Detection, Yes/No vocabulary test 1 Level 1 (Meara 1992)
#tasks_n / evaluation = feedback of intervention group on number of tasks completed and pleasantness/usefulness/novelty
#T1/T2/T3 = pre-/post-/delayed post-test vocabulary learning activity, cog = cognates

#Improvement from T1 to T2 and T3 and overall score on vocabulary learning activities
data$T2T1cog <- data$T2cog - data$T1cog #improvement on cognates from T1 to T2
data$T3T1cog <- data$T3cog - data$T1cog #improvement on cognates from T1 to T3
data$overall <- data$T1total + data$T2total + data$T3total #overall performance across three tests on all items
data$cognates <- data$T1cog + data$T2cog + data$T3cog #overall performance across three tests on cognates

#Improvement from T1 to T2 on cognates by correspondence (proportional by number of items tested)
data$T2T1tsz <- (data$T2cogtsz - data$T1cogtsz)/6
data$T2T1pf <- (data$T2cogpf - data$T1cogpf)/4
data$T2T1thdt <- (data$T2cogdth - data$T1cogdth)/7
data$T2T1ck <- (data$T2cogck - data$T1cogck)/5
data$T2T1kch <- (data$T2cogkch - data$T1cogkch)/2

#Improvement from T1 to T3 on cognates by correspondence (proportional by number of items tested)
data$T3T1tsz <- (data$T3cogtsz - data$T1cogtsz)/6
data$T3T1pf <- (data$T3cogpf - data$T1cogpf)/4
data$T3T1thdt <- (data$T3cogdth - data$T1cogdth)/7
data$T3T1ck <- (data$T3cogck - data$T1cogck)/5
data$T3T1kch <- (data$T3cogkch - data$T1cogkch)/2

#Improvement by testing mode (receptive / productive)
data$T2T1rec <- data$T2cog_r - data$T1cog_p
data$T3T1rec <- data$T3cog_r - data$T1cog_p
data$T2T1pro <- data$T2cog_p - data$T1cog_p
data$T3T1pro <- data$T3cog_p - data$T1cog_p

#sum-code treatment groups and center Yes/No test
data$n.Group <- ifelse(data$Group == "intervention", 1, 0)
data$c.wnw_istd <- data$wnw_istd - mean(data$wnw_istd, na.rm = TRUE)

#Create subset intervention group only
dataint <- subset(data,n.Group==1)



######################### INITIAL DIFFERENCES ###############################

#Boxplots T1 by treatment (vocabulary learning activity and yes-no test) 
yesnobytreat<- ggplot(data = data, 
                         aes(x = Group, 
                             y = (wnw_istd), color = Group)) +
  scale_color_grey(start=0.6, end=0.1) +
  theme_classic() +
  geom_boxplot() + 
  geom_point(position = position_jitter(width = 0.4,
                                        height = 0.0),
             shape = 1) +
  xlab("Treatment group") + 
  ylab("Performance") + 
  theme_bw() +
  ggtitle("Yes/No test",
          sub = "initial vocabulary knowledge")

T1cogbytreat <- ggplot(data = data, 
                         aes(x = Group, 
                             y = (T1cog), color = Group)) +
  scale_color_grey(start=0.6, end=0.1) +
  theme_classic() +
  geom_boxplot() + 
  geom_point(position = position_jitter(width = 0.4,
                                        height = 0.0),
             shape = 1) +
  xlab("Treatment group") + 
  ylab("Performance") + 
  theme_bw() +
  ggtitle("Performance on cognates",
          sub ="Vocabulary learning activity T1") 

ggsave(file = "T1cogbytreat.eps", plot=T1cogbytreat, width = 3.10, height= 4.14)
ggsave(file = "yesnobytreat.eps", plot=yesnobytreat, width = 3.10, height= 4.14)

# Group initial differences between treatment groups
t.test(data$T1total~data$Group)
t.test(data$T1cog~data$Group)
t.test(data$wnw_istd~data$Group)

chisq.test(table(data$Group,data$Gender),correct=FALSE)
chisq.test(table(data$Group,data$Grade),correct=FALSE)
chisq.test(table(data$Group,data$lang_groups),correct=FALSE)


################## IMPROVEMENT BY TREATMENT AND YES/NO TEST  #######################

# Boxplots improvement on cognates by treatment across all classes
impbytreat1 <- ggplot(data = data, 
                      aes(x = Group, 
                          y = T2T1cog)) +
  geom_boxplot() + 
  geom_point(position = position_jitter(width = 0.4,
                                        height = 0.0),
             shape = 1) +
  xlab("Treatment group") + 
  ylab("Improvement T2-T1") + 
  theme_bw() +
  ggtitle("Improvement on cognates T2-T1", 
          sub = "by treatment group") 

impbytreat2 <- ggplot(data = data, 
                      aes(x = Group, 
                          y = (T3T1cog))) +
  geom_boxplot() + 
  geom_point(position = position_jitter(width = 0.4,
                                        height = 0.0),
             shape = 1) +
  xlab("Treatment group") + 
  ylab("Improvement T3-T1") + 
  theme_bw() + 
  ggtitle("Improvement on cognates T3-T1", 
          sub = "by treatment group") 

ggsave(file = "impbytreat1.eps", plot=impbytreat1, width = 3.10, height= 4.14)
ggsave(file = "impbytreat2.eps", plot=impbytreat2, width = 3.10, height= 4.14)


#Boxplots Improvement by treatment and class with colors
T2T1byclass <- ggplot(data = data, 
                      aes(x = fct_reorder(Class,(T2T1cog)), 
                          y = (T2T1cog), color = Group)) +
  geom_boxplot() + 
  geom_point(position = position_jitter(width = 0.4,
                                        height = 0.0),
             shape = 1) +
  xlab("Class") + 
  ylab("Improvement T2-T1") + 
  theme_bw() +
  ggtitle("Improvement on cognates from T1 to T2",
          sub = "by class") 

T3T1byclass <- ggplot(data = data, 
                      aes(x = fct_reorder(Class,(T3T1cog)), 
                          y = (T3T1cog), color = Group)) +
  geom_boxplot() + 
  geom_point(position = position_jitter(width = 0.4,
                                        height = 0.0),
             shape = 1) +
  xlab("Class") + 
  ylab("Improvement T3-T1") + 
  theme_bw() +
  ggtitle("Improvement on cognates from T1 to T3", 
          sub = "by class") 

ggsave(file = "T2T1byclass.eps", plot=T2T1byclass, width = 6.21, height= 3.55)
ggsave(file = "T3T1byclass.eps", plot=T3T1byclass, width = 6.21, height= 3.55)


#Boxplots Improvement by treatment and class grey scales
T2T1byclassgrey <- ggplot(data = data, 
                      aes(x = fct_reorder(Class,(T2T1cog)), 
                          y = (T2T1cog), color = Group),
                      outlier.shape = NA) +
  scale_color_grey(start=0.6, end=0.1) +
  theme_classic() +
  geom_boxplot() + 
  geom_point(position = position_jitter(width = 0.4,
                                        height = 0.0),
             shape = 1) +
  xlab("Class") + 
  ylab("Improvement T2-T1") + 
  theme_bw() +
  ggtitle("Improvement on cognates from T1 to T2",
          sub = "by class") 

T3T1byclassgrey <- ggplot(data = data, 
                      aes(x = fct_reorder(Class,(T3T1cog)), 
                          y = (T3T1cog), color = Group)) +
  scale_color_grey(start=0.6, end=0.1) +
  theme_classic() +
  geom_boxplot() + 
  geom_point(position = position_jitter(width = 0.4,
                                        height = 0.0),
             shape = 1) +
  xlab("Class") + 
  ylab("Improvement T3-T1") + 
  theme_bw() +
  ggtitle("Improvement on cognates from T1 to T3", 
          sub = "by class") 

ggsave(file = "T2T1byclassgrey.eps", plot=T2T1byclassgrey, width = 6.21, height= 3.55)
ggsave(file = "T3T1byclassgrey.eps", plot=T3T1byclassgrey, width = 6.21, height= 3.55)

#Linear Regression Model
summary(lmer(T2T1cog~n.Group*c.wnw_istd+(1|Class), data=data))
summary(lmer(T3T1cog~n.Group*c.wnw_istd+(1|Class), data=data))



################## IMPROVEMENT BY TYPE OF CORRESPONDENCE #######################

#Improvement by class per correspondence rule
imp_cog_rule <- data %>% 
  group_by(Class, Group, n.Group) %>% 
  summarise(
    mean_T2T1_ck = mean(T2T1ck), mean_T3T1_ck = mean(T3T1ck),
    mean_T2T1_pf = mean(T2T1pf), mean_T3T1_pf = mean(T3T1pf),
    mean_T2T1_thdt = mean(T2T1thdt), mean_T3T1_thdt = mean(T3T1thdt),
    mean_T2T1_tsz = mean(T2T1tsz), mean_T3T1_tsz = mean(T3T1tsz),
    mean_T2T1_kch = mean(T2T1kch), mean_T3T1_kch = mean(T3T1kch),
    .groups = "drop"
  )

#rearrange data
imp_rule <- imp_cog_rule %>%
  pivot_longer(cols = starts_with("mean"),
  names_to = c("time", "rule"),
  names_pattern = "mean_(.*)_(.*)",
  values_to = "mean",
  values_drop_na = TRUE)
imp_rule$rule <- factor(imp_rule$rule,
                            levels=c("ck", "pf", "thdt", "tsz", "kch"))

#boxplot
impbycorrespondence <- ggplot(data = imp_rule,
       aes(x = Group, 
           y = (mean), color = Group)) +
  ylim(c(-0.4, +0.4)) +
  theme_classic() +
  geom_boxplot() + 
  geom_point(position = position_jitter(width = 0.1,
                                        height = 0.0),
             shape = 1) +
  facet_grid(time~rule) +
  xlab("Treatment group") + 
  ylab("Progress") + 
  theme_bw() +
  ggtitle("Improvement by type of correspondence",
          sub = "by treatment (M per class) and test time")

ggsave(file = "impbycorrespondence.eps", plot=impbycorrespondence, width = 6.21, height= 3.55)

#Linear Mixed-Effect Regression Models T2-T1
summary(lmer(T2T1ck~n.Group+(1|Class), data=data))
summary(lmer(T2T1pf~n.Group+(1|Class), data=data))
summary(lmer(T2T1thdt~n.Group+(1|Class), data=data))
summary(lmer(T2T1tsz~n.Group+(1|Class), data=data))
summary(lmer(T2T1kch~n.Group+(1|Class), data=data))

#Linear Mixed-Effect Regression Models T3-T1
summary(lmer(T3T1ck~n.Group+(1|Class), data=data))
summary(lmer(T3T1pf~n.Group+(1|Class), data=data))
summary(lmer(T3T1thdt~n.Group+(1|Class), data=data))
summary(lmer(T3T1tsz~n.Group+(1|Class), data=data))
summary(lmer(T3T1kch~n.Group+(1|Class), data=data))



####################### IMPROVEMENT BY TEST MODE ########################################

#Improvement by class per test mode
imp_cog_mode <- data %>% 
  group_by(Class, Group, n.Group) %>% 
  summarise(
    mean_T2T1_receptive = mean(T2T1rec), mean_T3T1_receptive = mean(T3T1rec),
    mean_T2T1_productive = mean(T2T1pro), mean_T3T1_productive = mean(T3T1pro),
    .groups = "drop"
  )

#rearrange data
impmode <- imp_cog_mode %>%
  pivot_longer(cols = starts_with("mean"),
               names_to = c("time", "rule"),
               names_pattern = "mean_(.*)_(.*)",
               values_to = "mean",
               values_drop_na = TRUE)
impmode$rule <- factor(impmode$rule,
                       levels=c("receptive", "productive"))
impmodeT2T1 <- subset(impmode,time=="T2T1") #progress by mode from T1 to T2
impmodeT3T1 <- subset(impmode,time=="T3T1") #progress by mode from T1 to T3
  

#boxplot
plotmodeT2T1 <- ggplot(data = impmodeT2T1,
                             aes(x = Group, 
                                 y = (mean), color = Group)) +
  ylim(c(-2.5, +4)) +
  theme_classic() +
  geom_boxplot() + 
  geom_point(position = position_jitter(width = 0.1,
                                        height = 0.0),
             shape = 1) +
  facet_grid(.~rule) +
  xlab("Treatment group") + 
  ylab("Improvement") + 
  theme_bw() +
  ggtitle("Improvement by test mode from T1 to T2",
          sub = "by treatment (M per class)")

plotmodeT3T1 <- ggplot(data = impmodeT3T1,
                   aes(x = Group, 
                       y = (mean), color = Group)) +
  ylim(c(-2.5, +4)) +
  theme_classic() +
  geom_boxplot() + 
  geom_point(position = position_jitter(width = 0.1,
                                        height = 0.0),
             shape = 1) +
  facet_grid(.~rule) +
  xlab("Treatment group") + 
  ylab("Improvement") + 
  theme_bw() +
  ggtitle("Improvement by test mode from T1 to T3",
          sub = "by treatment (M per class)")

theme_set(theme_pubr())
impbymode <- ggarrange(plotmodeT2T1, plotmodeT3T1,
                    ncol = 2, nrow = 1)

ggsave(file = "impbytestmode.eps", plot=impbymode, width = 6.21, height= 3.55)


#linear regression models by testing mode
summary(lmer(T2T1rec~n.Group+(1|Class), data=data))
summary(lmer(T3T1rec~n.Group+(1|Class), data=data))
summary(lmer(T2T1pro~n.Group+(1|Class), data=data))
summary(lmer(T3T1pro~n.Group+(1|Class), data=data))

###################### ATTITUDE #############################
cor.test(dataint$evaluation, dataint$T2T1cog) #attitude towards intervention with progress
cor.test(dataint$evaluation, dataint$T3T1cog)
cor.test(dataint$tasks_n, dataint$T2T1cog) #number of tasks completed with progress
cor.test(dataint$tasks_n, dataint$T3T1cog)